@@ -1,17 +1,9 @@
-# This file is part of Pynguin.
+#  This file is part of Pynguin.
 #
-# Pynguin is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+#  SPDX-FileCopyrightText: 2019–2020 Pynguin Contributors
 #
-# Pynguin is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
+#  SPDX-License-Identifier: LGPL-3.0-or-later
 #
-# You should have received a copy of the GNU Lesser General Public License
-# along with Pynguin.  If not, see <https://www.gnu.org/licenses/>.
 """Pynguin is an automated unit test generation framework for Python.
 
 This module provides the main entry location for the program execution from the command
@@ -31,7 +23,8 @@ from pynguin.generator import Pynguin
 
 def _create_argument_parser() -> argparse.ArgumentParser:
     parser = simple_parsing.ArgumentParser(
-        description="Pynguin is an automatic random unit test generation framework for Python."
+        add_dest_to_option_strings=False,
+        description="Pynguin is an automatic unit test generation framework for Python",
     )
     parser.add_argument(
         "--version", action="version", version="%(prog)s " + __version__
