@@ -1,17 +1,9 @@
-# This file is part of Pynguin.
+#  This file is part of Pynguin.
 #
-# Pynguin is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+#  SPDX-FileCopyrightText: 2019–2020 Pynguin Contributors
 #
-# Pynguin is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
+#  SPDX-License-Identifier: LGPL-3.0-or-later
 #
-# You should have received a copy of the GNU Lesser General Public License
-# along with Pynguin.  If not, see <https://www.gnu.org/licenses/>.
 """Provides a configuration interface for the test generator."""
 import dataclasses
 import enum
@@ -49,8 +41,6 @@ class Algorithm(str, enum.Enum):
     proposed by Randoop (cf. Pacheco et al. Feedback-directed random test generation.
     Proc. ICSE 2007)."""
 
-    RANDOOPY_MONKEYTYPE = "RANDOOPY_MONKEYTYPE"
-
     WSPY = "WSPY"
     """A whole-suite test generation approach similar to the one proposed by EvoSuite
     (cf. Fraser and Arcuri. EvoSuite: Automatic Test Suite Generation for
@@ -259,9 +249,6 @@ class Configuration(Serializable):
     stopping_condition: StoppingCondition = StoppingCondition.MAX_TIME
     """What condition should be checked to end the search/test generation."""
 
-    monkey_type_execution: int = 1
-    """Execute MonkeyType in each n-th iteration of the algorithm"""
-
     type_inference_strategy: TypeInferenceStrategy = TypeInferenceStrategy.TYPE_HINTS
     """The strategy for type-inference that shall be used"""
 
