@@ -1,17 +1,9 @@
-# This file is part of Pynguin.
+#  This file is part of Pynguin.
 #
-# Pynguin is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+#  SPDX-FileCopyrightText: 2019–2020 Pynguin Contributors
 #
-# Pynguin is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
+#  SPDX-License-Identifier: LGPL-3.0-or-later
 #
-# You should have received a copy of the GNU Lesser General Public License
-# along with Pynguin.  If not, see <https://www.gnu.org/licenses/>.
 """Pynguin is an automated unit test generation framework for Python.
 
 The framework generates unit tests for a given Python module.  For this it
@@ -35,9 +27,6 @@ import pynguin.configuration as config
 import pynguin.testcase.testcase as tc
 import pynguin.testsuite.testsuitechromosome as tsc
 from pynguin.analyses.seeding.staticconstantseeding import StaticConstantSeeding
-from pynguin.generation.algorithms.randoopy.randomtestmonkeytypestrategy import (
-    RandomTestMonkeyTypeStrategy,
-)
 from pynguin.generation.algorithms.randoopy.randomteststrategy import RandomTestStrategy
 from pynguin.generation.algorithms.testgenerationstrategy import TestGenerationStrategy
 from pynguin.generation.algorithms.wspy.wholesuiteteststrategy import (
@@ -277,7 +266,6 @@ class Pynguin:
         Callable[[TestCaseExecutor, TestCluster], TestGenerationStrategy],
     ] = {
         config.Algorithm.RANDOOPY: RandomTestStrategy,
-        config.Algorithm.RANDOOPY_MONKEYTYPE: RandomTestMonkeyTypeStrategy,
         config.Algorithm.WSPY: WholeSuiteTestStrategy,
     }
 
